@@ -41,7 +41,7 @@ _REVERSE_CLOSURE = '/reverseClosure'
 _CONSUMER_SERVICE_RESOURCE = '%s/services/%s'
 _CONSUMER_POLICY_DEFAULT = '/consumerPolicies/%s'
 _EFFECTIVE_POLICY = '/effectivePolicy'
-_GOOGLE_GROUP_RESOURCE = 'groups/googleServices'
+_GOOGLE_CATEGORY_RESOURCE = 'categories/google'
 _LIMIT_OVERRIDE_RESOURCE = '%s/consumerOverrides/%s'
 _VALID_CONSUMER_PREFIX = frozenset({'projects/', 'folders/', 'organizations/'})
 _V1_VERSION = 'v1'
@@ -103,39 +103,6 @@ def GetConsumerPolicyV2Alpha(policy_name):
     )
 
 
-# TODO(b/309115642) Remove after the migration is completed.
-def GetConsumerPolicyV2(policy_name):
-  """Make API call to get a consumer policy.
-
-  Args:
-    policy_name: The name of a consumer policy. Currently supported format
-      '{resource_type}/{resource_name}/consumerPolicies/default'. For example,
-      'projects/100/consumerPolicies/default'.
-
-  Raises:
-    exceptions.GetConsumerPolicyPermissionDeniedException: when getting a
-      consumer policy fails.
-    apitools_exceptions.HttpError: Another miscellaneous error with the service.
-
-  Returns:
-    The consumer policy
-  """
-  client = _GetClientInstance('v2')
-  messages = client.MESSAGES_MODULE
-
-  request = messages.ServiceusageConsumerPoliciesGetRequest(name=policy_name)
-
-  try:
-    return client.consumerPolicies.Get(request)
-  except (
-      apitools_exceptions.HttpForbiddenError,
-      apitools_exceptions.HttpNotFoundError,
-  ) as e:
-    exceptions.ReraiseError(
-        e, exceptions.GetConsumerPolicyPermissionDeniedException
-    )
-
-
 def TestEnabled(name: str, service: str):
   """Make API call to test enabled.
 
@@ -178,7 +145,7 @@ def GetEffectivePolicyV2Alpha(name: str, view: str = 'BASIC'):
     name: The name of the effective policy.Currently supported format
       '{resource_type}/{resource_name}/effectivePolicy'. For example,
       'projects/100/effectivePolicy'.
-    view: The view of the effective policy to use. Default: 'BASIC'.
+    view: The view of the effective policy to use. The default view is 'BASIC'.
 
   Raises:
     exceptions.GetEffectiverPolicyPermissionDeniedException: when getting a
@@ -194,7 +161,7 @@ def GetEffectivePolicyV2Alpha(name: str, view: str = 'BASIC'):
     view_type = (
         messages.ServiceusageGetEffectivePolicyRequest.ViewValueValuesEnum.EFFECTIVE_POLICY_VIEW_BASIC
     )
-  elif view == 'FULL':
+  else:
     view_type = (
         messages.ServiceusageGetEffectivePolicyRequest.ViewValueValuesEnum.EFFECTIVE_POLICY_VIEW_FULL
     )
@@ -247,119 +214,86 @@ def GetEffectivePolicyV2(name):
     )
 
 
-def FetchValueInfo(resource, values):
-  """Make API call to fetch value info for the services.
+def BatchGetService(parent, services):
+  """Make API call to get service state for multiple services .
 
   Args:
-    resource: The target resource.
-    values: The name of the value to get metadata. A single request can get a
-      maximum of 20 services at a time. If more than 20 services are specified,
-      the request will fail.
+    parent: Parent resource to get service state for. format-"projects/100",
+      "folders/101" or "organizations/102".
+    services: Services. Current supported value:(format:
+      "{resource}/{resource_Id}/services/{service}").
 
   Raises:
-    exceptions.FetchValueInfoPermissionDeniedException: when
-      fetching  value info fails.
+    exceptions.BatchGetServicePermissionDeniedException: when getting batch
+      service state for services in the resource.
     apitools_exceptions.HttpError: Another miscellaneous error with the service.
 
   Returns:
-    Value Info for the specificed values.
+    Service state of the given resource.
   """
-  client = _GetClientInstance('v2')
+  client = _GetClientInstance('v2alpha')
   messages = client.MESSAGES_MODULE
 
-  request = messages.ServiceusageFetchValueInfoRequest(
-      fetchValueInfoRequest=messages.FetchValueInfoRequest(values=values),
-      name=resource,
+  request = messages.ServiceusageServicesBatchGetRequest(
+      parent=parent,
+      services=services,
+      view=messages.ServiceusageServicesBatchGetRequest.ViewValueValuesEnum.SERVICE_STATE_VIEW_FULL,
   )
 
   try:
-    return client.v2.FetchValueInfo(request)
+    return client.services.BatchGet(request)
   except (
       apitools_exceptions.HttpForbiddenError,
       apitools_exceptions.HttpNotFoundError,
   ) as e:
     exceptions.ReraiseError(
-        e, exceptions.FetchValueInfoPermissionDeniedException
+        e, exceptions.BatchGetServicePermissionDeniedException
     )
 
 
-def FetchPublicValueInfo(values):
-  """Make API call to fetch public value info for the services.
+def ListCategoryServices(resource, category, page_size=200, limit=sys.maxsize):
+  """Make API call to list category services .
 
   Args:
-    values: The name of the value to get metadata. A single request can get a
-      maximum of 20 services at a time. If more than 20 services are specified,
-      the request will fail.
+    resource: resource to get list for. format-"projects/100", "folders/101" or
+      "organizations/102".
+    category: category to get list for. format-"catgeory/<category>".
+    page_size: The page size to list.default=200
+    limit: The max number of services to display.
 
   Raises:
-    exceptions.FetchPublicValueInfoPermissionDeniedException: when
-      fetching public value info fails.
+    exceptions.ListCategoryServicespermissionDeniedException: when listing the
+    services the parent category includes.
     apitools_exceptions.HttpError: Another miscellaneous error with the service.
 
   Returns:
-   Public Value Info for the specificed values.
+    The services the parent category includes.
   """
-  client = _GetClientInstance('v2')
+  client = _GetClientInstance('v2alpha')
   messages = client.MESSAGES_MODULE
 
-  request = messages.FetchPublicValueInfoRequest(
-      values=values,
+  request = messages.ServiceusageCategoriesCategoryServicesListRequest(
+      parent='{}/{}'.format(resource, category),
   )
 
   try:
-    return client.publicValueInfo.Fetch(request)
+    return list_pager.YieldFromList(
+        _Lister(client.categories_categoryServices),
+        request,
+        limit=limit,
+        batch_size_attribute='pageSize',
+        batch_size=page_size,
+        field='services',
+    )
   except (
       apitools_exceptions.HttpForbiddenError,
       apitools_exceptions.HttpNotFoundError,
   ) as e:
     exceptions.ReraiseError(
-        e, exceptions.FetchPublicValueInfoPermissionDeniedException
+        e, exceptions.ListCategoryServicespermissionDeniedException
     )
 
 
-# TODO(b/309115642) Remove after the migration is completed.
-def UpdateConsumerPolicyV2(consumerpolicy, name, force=False):
-  """Make API call to update a consumer policy.
-
-  Args:
-    consumerpolicy: The consumer policy to update.
-    name: The resource name of the policy. Currently supported format
-      '{resource_type}/{resource_name}/consumerPolicies/default. For example,
-      'projects/100/consumerPolicies/default'.
-    force: Disable service with usage within last 30 days or disable recently
-      enabled service.
-
-  Raises:
-    exceptions.UpdateConsumerPolicyPermissionDeniedException: when updating a
-      consumer policy fails.
-    apitools_exceptions.HttpError: Another miscellaneous error with the service.
-
-  Returns:
-    Updated consumer policy
-  """
-  client = _GetClientInstance('v2')
-  messages = client.MESSAGES_MODULE
-
-  request = messages.ServiceusageUpdateConsumerPolicyRequest(
-      consumerPolicy=consumerpolicy, name=name, force=force
-  )
-
-  try:
-    return client.v2.UpdateConsumerPolicy(request)
-  except (
-      apitools_exceptions.HttpForbiddenError,
-      apitools_exceptions.HttpNotFoundError,
-  ) as e:
-    exceptions.ReraiseError(
-        e, exceptions.UpdateConsumerPolicyPermissionDeniedException
-    )
-  except apitools_exceptions.HttpBadRequestError as e:
-    log.status.Print(
-        'Provide the --force flag if you wish to force disable services.'
-    )
-    exceptions.ReraiseError(e, exceptions.Error)
-
-
 def UpdateConsumerPolicyV2Alpha(consumerpolicy, name, force=False):
   """Make API call to update a consumer policy.
 
@@ -404,74 +338,7 @@ def UpdateConsumerPolicyV2Alpha(consumerpolicy, name, force=False):
     exceptions.ReraiseError(e, exceptions.Error)
 
 
-def GetReverseClosure(resource, service):
-  """Make API call to get reverse dependency of a specific service.
-
-  Args:
-    resource: The target resource.
-    service: The identifier of the service to get reversed depenedency of.
-
-  Raises:
-    exceptions.GetReverseDependencyClosurePermissionDeniedException: when
-      getting a reverse dependency closure for resource and service fails.
-    apitools_exceptions.HttpError: Another miscellaneous error with the service.
-
-  Returns:
-    Reverse dependency closure
-  """
-  client = _GetClientInstance('v2')
-  messages = client.MESSAGES_MODULE
-
-  request = messages.ServiceusageServicesGetReverseClosureRequest(
-      name=resource + '/' + _SERVICE_RESOURCE % service + _REVERSE_CLOSURE
-  )
-
-  try:
-    return client.services.GetReverseClosure(request)
-  except (
-      apitools_exceptions.HttpForbiddenError,
-      apitools_exceptions.HttpNotFoundError,
-  ) as e:
-    exceptions.ReraiseError(
-        e, exceptions.GetReverseDependencyClosurePermissionDeniedException
-    )
-
-
-def ListFlattenedMembers(resource, service_group):
-  """Make API call to list flattened members of a specific service group.
-
-  Args:
-    resource: The target resource.
-    service_group: Service group which owns this collection of flattened
-      members, for example,
-      'services/compute.googleapis.com/groups/dependencies'.
-
-  Raises:
-    exceptions.ListFlattenedMembersPermissionDeniedException: when listing
-      flattened members fails.
-    apitools_exceptions.HttpError: Another miscellaneous error with the service.
-
-  Returns:
-    Flattened members in the given service group.
-  """
-  client = _GetClientInstance('v2')
-  messages = client.MESSAGES_MODULE
-
-  request = messages.ServiceusageServicesGroupsFlattenedMembersListRequest(
-      parent=resource + '/' + service_group
-  )
-
-  try:
-    return client.services_groups_flattenedMembers.List(request)
-  except (
-      apitools_exceptions.HttpForbiddenError,
-      apitools_exceptions.HttpNotFoundError,
-  ) as e:
-    exceptions.ReraiseError(
-        e, exceptions.ListFlattenedMembersPermissionDeniedException
-    )
-
-
+# TODO(b/309115642) Remove after the migration is completed.
 def ListGroupMembers(resource, service_group, page_size=50, limit=sys.maxsize):
   """Make API call to list group members of a specific service group.
 
@@ -515,13 +382,65 @@ def ListGroupMembers(resource, service_group, page_size=50, limit=sys.maxsize):
     )
 
 
-def ListDescendantServices(resource, service_group):
-  """Make API call to list descendant services of a specific service group.
+def ListGroupMembersV2Alpha(
+    resource: str,
+    service_group: str,
+    page_size: int = 50,
+    limit: int = sys.maxsize,
+):
+  """Make API call to list group members of a specific service group.
 
   Args:
     resource: The target resource.
+    service_group: Service group which owns a collection of group members, for
+      example, 'services/compute.googleapis.com/groups/dependencies'.
+    page_size: The page size to list. The default page_size is 50.
+    limit: The max number of services to display.
+
+  Raises:
+    exceptions.ListGroupMembersPermissionDeniedException: when listing
+      group members fails.
+    apitools_exceptions.HttpError: Another miscellaneous error with the service.
+
+  Returns:
+    Group members in the given service group.
+  """
+  client = _GetClientInstance('v2alpha')
+  messages = client.MESSAGES_MODULE
+
+  request = messages.ServiceusageServicesGroupsMembersListRequest(
+      parent=resource + '/' + service_group
+  )
+
+  try:
+    return list_pager.YieldFromList(
+        _Lister(client.services_groups_members),
+        request,
+        limit=limit,
+        batch_size_attribute='pageSize',
+        batch_size=page_size,
+        field='memberStates',
+    )
+  except (
+      apitools_exceptions.HttpForbiddenError,
+      apitools_exceptions.HttpNotFoundError,
+  ) as e:
+    exceptions.ReraiseError(
+        e, exceptions.ListGroupMembersPermissionDeniedException
+    )
+
+
+def ListDescendantServices(
+    resource: str, service_group: str, page_size: int = 50
+):
+  """Make API call to list descendant services of a specific service group.
+
+  Args:
+    resource: The target resource in the format:
+      '{resource_type}/{resource_name}'.
     service_group: Service group, for example,
       'services/compute.googleapis.com/groups/dependencies'.
+    page_size: The page size to list. The default page_size is 50.
 
   Raises:
     exceptions.ListDescendantServicesPermissionDeniedException: when listing
@@ -539,7 +458,13 @@ def ListDescendantServices(resource, service_group):
   )
 
   try:
-    return client.services_groups_descendantServices.List(request)
+    return list_pager.YieldFromList(
+        _Lister(client.services_groups_descendantServices),
+        request,
+        batch_size_attribute='pageSize',
+        batch_size=page_size,
+        field='services',
+    )
   except (
       apitools_exceptions.HttpForbiddenError,
       apitools_exceptions.HttpNotFoundError,
@@ -549,6 +474,47 @@ def ListDescendantServices(resource, service_group):
     )
 
 
+def ListAncestorGroups(resource: str, service: str, page_size=50):
+  """Make API call to list ancestor groups that depend on the service.
+
+  Args:
+    resource: The target resource.format : '{resource_type}/{resource_name}'.
+    service: The identifier of the service to get ancestor groups of, for
+      example, 'services/compute.googleapis.com'.
+    page_size: The page size to list.The default page_size is 50.
+
+  Raises:
+    exceptions.ListAncestorGroupsPermissionDeniedException: when listing
+      ancestor group fails.
+    apitools_exceptions.HttpError: Another miscellaneous error with the service.
+
+  Returns:
+    Ancestor groups that depend on the service.
+  """
+  client = _GetClientInstance('v2alpha')
+  messages = client.MESSAGES_MODULE
+
+  request = messages.ServiceusageServicesAncestorGroupsListRequest(
+      name=f'{resource}/{service}'
+  )
+
+  try:
+    return list_pager.YieldFromList(
+        _Lister(client.services_ancestorGroups),
+        request,
+        batch_size_attribute='pageSize',
+        batch_size=page_size,
+        field='groups',
+    )
+  except (
+      apitools_exceptions.HttpForbiddenError,
+      apitools_exceptions.HttpNotFoundError,
+  ) as e:
+    exceptions.ReraiseError(
+        e, exceptions.ListAncestorGroupsPermissionDeniedException
+    )
+
+
 def AddEnableRule(
     services,
     project,
@@ -597,7 +563,7 @@ def AddEnableRule(
       list_descendant_services = ListDescendantServices(
           resource_name, _SERVICE_RESOURCE % service + _DEPENDENCY_GROUP
       )
-      for member in list_descendant_services.services:
+      for member in list_descendant_services:
         services_to_enabled.add(member.serviceName)
 
     if policy.enableRules:
@@ -660,21 +626,24 @@ def RemoveEnableRule(
   policy_name = resource_name + _CONSUMER_POLICY_DEFAULT % consumer_policy_name
 
   try:
-    current_policy = GetConsumerPolicyV2(policy_name)
+    current_policy = GetConsumerPolicyV2Alpha(policy_name)
 
-    reverse_closure = GetReverseClosure(resource_name, service)
+    ancestor_groups = ListAncestorGroups(
+        resource_name, _SERVICE_RESOURCE % service
+    )
 
     if not force:
       enabled = set()
 
       for enable_rule in current_policy.enableRules:
-        enabled.update(enable_rule.values)
+        enabled.update(enable_rule.services)
 
       enabled_dependents = set()
 
-      for value in reverse_closure.values:
-        if value in enabled:
-          enabled_dependents.add(value)
+      for ancestor_group in ancestor_groups:
+        service_name = '/'.join(str.split(ancestor_group.groupName, '/')[:2])
+        if service_name in enabled:
+          enabled_dependents.add(service_name)
 
       if enabled_dependents:
         enabled_dependents = ','.join(enabled_dependents)
@@ -687,21 +656,22 @@ def RemoveEnableRule(
             ' services.'
         )
 
-    to_remove = {reverse_closure.service}
-    to_remove.update(reverse_closure.values)
+    to_remove = {_SERVICE_RESOURCE % service}
+    for ancestor_group in ancestor_groups:
+      to_remove.add('/'.join(str.split(ancestor_group.groupName, '/')[:2]))
 
     updated_consumer_poicy = copy.deepcopy(current_policy)
     updated_consumer_poicy.enableRules.clear()
 
     for enable_rule in current_policy.enableRules:
       rule = copy.deepcopy(enable_rule)
-      for value in enable_rule.values:
-        if value in to_remove:
-          rule.values.remove(value)
-      if rule.values:
+      for service_name in enable_rule.services:
+        if service_name in to_remove:
+          rule.services.remove(service_name)
+      if rule.services:
         updated_consumer_poicy.enableRules.append(rule)
 
-    return UpdateConsumerPolicyV2(
+    return UpdateConsumerPolicyV2Alpha(
         updated_consumer_poicy, policy_name, force=force
     )
   except (
@@ -862,7 +832,7 @@ class _Lister:
     return self.service_usage.List(request, global_params=global_params)
 
 
-def ListServicesV2(
+def ListServicesV2Alpha(
     project,
     enabled,
     page_size,
@@ -896,43 +866,37 @@ def ListServicesV2(
     resource_name = _ORGANIZATION_RESOURCE % organization
 
   services = {}
+  parent = []
   try:
     if enabled:
       policy_name = resource_name + _EFFECTIVE_POLICY
-      consumerpolicy = GetEffectivePolicyV2(policy_name).consumerPolicy
+      effectivepolicy = GetEffectivePolicyV2Alpha(policy_name)
 
-      for rules in consumerpolicy.enableRules:
-        for value in rules.values:
+      for rules in effectivepolicy.enableRules:
+        for value in rules.services:
           if limit == 0:
             break
+          parent.append(f'{resource_name}/{value}')
           services[value] = ''
           limit -= 1
 
-      service_list = list(services.keys())
-      for value in range(0, len(service_list), 20):
-        response = FetchValueInfo(
-            resource_name, values=service_list[value : value + 20]
-        )
-        for value_info in response.valueInfos:
-          services[value_info.serviceValue.name] = value_info.title
+      for value in range(0, len(parent), 20):
+        response = BatchGetService(resource_name, parent[value : value + 20])
+        for service_state in response.services:
+          service_name = '/'.join(service_state.name.split('/')[2:])
+          services[service_name] = service_state.service.displayName
 
     else:
-      for members_info in ListGroupMembers(
-          resource_name, _GOOGLE_GROUP_RESOURCE, page_size, limit
+      for category_service in ListCategoryServices(
+          resource_name, _GOOGLE_CATEGORY_RESOURCE, page_size, limit
       ):
-        services[members_info.name] = ''
-
-      service_list = list(services.keys())
-      # TODO(b/274633761)Switch to FetchValueInfo once the IAM permission manual
-      # check issue is fixed and test it.
-      for value in range(0, len(service_list), 20):
-        response = FetchPublicValueInfo(values=service_list[value : value + 20])
-        for value_info in response.valueInfos:
-          services[value_info.serviceValue.name] = value_info.title
+        services[category_service.service.name] = (
+            category_service.service.displayName
+        )
 
     result = []
     service_info = collections.namedtuple('ServiceList', ['name', 'title'])
-    for service in service_list:
+    for service in services:
       result.append(service_info(name=service, title=services[service]))
 
     return result
