@@ -32,8 +32,8 @@ from googlecloudsdk.core import log
 from googlecloudsdk.core import properties
 from googlecloudsdk.core.console import console_io
 from googlecloudsdk.core.credentials import creds as c_creds
-from googlecloudsdk.core.credentials import store as c_store
 from googlecloudsdk.core.util import files
+from googlecloudsdk.core.util import platforms
 
 from oauth2client import client
 from oauth2client import service_account
@@ -42,12 +42,6 @@ from oauth2client.contrib import gce as oauth2client_gce
 
 SERVICEUSAGE_PERMISSION = 'serviceusage.services.use'
 
-ACCOUNT_TABLE_FORMAT = ("""\
-    table[title='Credentialed Accounts'](
-        status.yesno(yes='*', no=''):label=ACTIVE,
-        account
-    )""")
-
 
 class MissingPermissionOnQuotaProjectError(c_creds.ADCError):
   """An error when ADC does not have permission to bill a quota project."""
@@ -57,26 +51,6 @@ class AddQuotaProjectError(c_creds.ADCError):
   """An error when quota project ID is added to creds that don't support it."""
 
 
-class _AcctInfo(object):
-  """An auth command resource list item.
-
-  Attributes:
-    account: The account name.
-    status: The account status, one of ['ACTIVE', ''].
-  """
-
-  def __init__(self, account, active):
-    self.account = account
-    self.status = 'ACTIVE' if active else ''
-
-
-def AllAccounts():
-  """The resource list return value for the auth command Run() method."""
-  active_account = properties.VALUES.core.account.Get()
-  return [_AcctInfo(account, account == active_account)
-          for account in c_store.AvailableAccounts()]
-
-
 def IsGceAccountCredentials(cred):
   """Checks if the credential is a Compute Engine service account credential."""
   # Import only when necessary to decrease the startup time. Move it to
@@ -203,11 +177,33 @@ def _AdcHasGivenPermissionOnProjectHelper(project_ref, permissions):
     properties.VALUES.auth.credential_file_override.Set(cred_file_override_old)
 
 
+# Create this function to ease unit test mocks.
+def GetAdcRealPath(adc_path):
+  return os.path.realpath(adc_path)
+
+
 def LogADCIsWritten(adc_path):
-  log.status.Print('\nCredentials saved to file: [{}]'.format(adc_path))
+  """Prints the confirmation when ADC file was successfully written."""
+  real_path = adc_path
+  if platforms.OperatingSystem.Current() == platforms.OperatingSystem.WINDOWS:
+    real_path = GetAdcRealPath(adc_path)
+  log.status.Print('\nCredentials saved to file: [{}]'.format(real_path))
   log.status.Print(
       '\nThese credentials will be used by any library that requests '
       'Application Default Credentials (ADC).')
+  # See https://bugs.python.org/issue40377 for the issue with python
+  # from Microsoft store. The ADC file is transparently redirected to a
+  # different path which client libraries do not expect, so cannot locate.
+  if real_path != adc_path:
+    log.warning('You may be running gcloud with a python interpreter installed '
+                'from Microsoft Store which is not supported by this command. '
+                'Run `gcloud topic startup` for instructions to select a '
+                'different python interpreter. Otherwise, you have to '
+                'set the environment variable `GOOGLE_APPLICATION_CREDENTIALS` '
+                'to the file path `{}`. See '
+                'https://cloud.google.com/docs/authentication/'
+                'getting-started#setting_the_environment_variable '
+                'for more information.'.format(real_path))
 
 
 def LogQuotaProjectAdded(quota_project):
@@ -299,17 +295,28 @@ def AddQuotaProjectToADC(quota_project):
     raise c_exc.BadFileException(
         'The application default credentials are not user credentials, quota '
         'project cannot be added.')
-  if not AdcHasGivenPermissionOnProject(
-      quota_project, permissions=[SERVICEUSAGE_PERMISSION]):
-    raise MissingPermissionOnQuotaProjectError(
-        'Cannot add the project "{}" to application default credentials (ADC) '
-        'as a quota project because the account in ADC does not have the '
-        '"{}" permission on this project.'.format(quota_project,
-                                                  SERVICEUSAGE_PERMISSION))
+
   credentials, _ = c_creds.GetGoogleAuthDefault().load_credentials_from_file(
       config.ADCFilePath())
+  previous_quota_project = credentials.quota_project_id
+
   adc_path = c_creds.ADC(credentials).DumpExtendedADCToFile(
       quota_project=quota_project)
+
+  try:
+    if not AdcHasGivenPermissionOnProject(
+        quota_project, permissions=[SERVICEUSAGE_PERMISSION]):
+      raise MissingPermissionOnQuotaProjectError(
+          'Cannot add the project "{}" to application default credentials (ADC) '
+          'as a quota project because the account in ADC does not have the '
+          '"{}" permission on this project.'.format(quota_project,
+                                                    SERVICEUSAGE_PERMISSION))
+  except Exception:
+    # Rollback the quota project before surfacing any exception that occurred.
+    c_creds.ADC(credentials).DumpExtendedADCToFile(
+        quota_project=previous_quota_project)
+    raise
+
   LogADCIsWritten(adc_path)
   LogQuotaProjectAdded(quota_project)
 
