@@ -870,22 +870,12 @@ class _BaseInstances(object):
           sql_messages.DatabaseInstance.SqlNetworkArchitectureValueValuesEnum.NEW_NETWORK_ARCHITECTURE
       )
 
-    if _IsAlpha(release_track):
-      if args.IsSpecified('simulate_maintenance_event'):
-        # Throw expection if both simulate maintenance event flag is enabled and
-        # maintenance version flag is found but not set to current version.
-        if (
-            args.IsSpecified('maintenance_version')
-            and args.maintenance_version != original.maintenanceVersion
-        ):
-          raise exceptions.ConflictingArgumentsException(
-              '--simulate_maintenance_event', '--maintenance_version'
-          )
-        instance_resource.maintenanceVersion = original.maintenanceVersion
-        api_util.InstancesV1Beta4.PrintAndConfirmSimulatedMaintenanceEvent()
+    if args.IsSpecified('simulate_maintenance_event'):
+      instance_resource.maintenanceVersion = original.maintenanceVersion
+      api_util.InstancesV1Beta4.PrintAndConfirmSimulatedMaintenanceEvent()
     # Have the simulate maintenance event flag take precedence.
-    # Maintenance_version flag is not exclusive to Alpha so print warning
-    # regardless of the release track.
+    # Confirm simulation, maintenance-version flag cannot be supplied with
+    # simulate-maintenance-event flag.
     if (
         args.IsSpecified('maintenance_version')
         and args.maintenance_version == original.maintenanceVersion
