@@ -28,7 +28,7 @@ from googlecloudsdk.command_lib.bigtable import arguments
 from googlecloudsdk.core import log
 
 
-@base.ReleaseTracks(base.ReleaseTrack.GA, base.ReleaseTrack.BETA)
+@base.ReleaseTracks(base.ReleaseTrack.GA)
 class UpdateAppProfile(base.CreateCommand):
   """Update a Bigtable app profile."""
 
@@ -76,12 +76,9 @@ class UpdateAppProfile(base.CreateCommand):
         command invocation.
 
     Raises:
-      ConflictingArgumentsException:
-          If both cluster and multi_cluster are present.
-          If both multi_cluster and transactional_writes are present.
-          If both cluster and restrict_to are present.
-      OneOfArgumentsRequiredException: If neither cluster or multi_cluster are
-          present.
+      ConflictingArgumentsException,
+      OneOfArgumentsRequiredException:
+        See app_profiles.Update(...)
 
     Returns:
       Long running operation.
@@ -93,8 +90,8 @@ class UpdateAppProfile(base.CreateCommand):
         multi_cluster=args.route_any,
         restrict_to=args.restrict_to,
         transactional_writes=args.transactional_writes,
-        force=args.force,
         priority=args.priority,
+        force=args.force,
     )
 
   def Run(self, args):
@@ -105,11 +102,9 @@ class UpdateAppProfile(base.CreateCommand):
         command invocation.
 
     Raises:
-      ConflictingArgumentsException:
-          If both cluster and multi_cluster are present.
-          If both multi_cluster and transactional_writes are present.
-      OneOfArgumentsRequiredException: If neither cluster or multi_cluster are
-          present.
+      ConflictingArgumentsException,
+      OneOfArgumentsRequiredException:
+        See _UpdateAppProfile(...)
 
     Returns:
       Updated resource.
@@ -136,8 +131,8 @@ class UpdateAppProfile(base.CreateCommand):
       )
 
 
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
-class UpdateAppProfileAlpha(UpdateAppProfile):
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
+class UpdateAppProfileBeta(UpdateAppProfile):
   """Update a Bigtable app profile."""
 
   @staticmethod
@@ -146,12 +141,8 @@ class UpdateAppProfileAlpha(UpdateAppProfile):
     (
         arguments.ArgAdder(parser)
         .AddDescription('app profile', required=False)
-        .AddAppProfileRouting(
-            required=False,
-            allow_failover_radius=True,
-            allow_row_affinity=True,
-        )
-        .AddIsolation()
+        .AddAppProfileRouting(required=False)
+        .AddIsolation(allow_data_boost=True)
         .AddForce('update')
         .AddAsync()
     )
@@ -165,14 +156,59 @@ class UpdateAppProfileAlpha(UpdateAppProfile):
         command invocation.
 
     Raises:
-      ConflictingArgumentsException:
-          If both cluster and multi_cluster are present.
-          If both multi_cluster and transactional_writes are present.
-          If both cluster and restrict_to are present.
-          If both cluster and failover_radius are present.
-          If both cluster and row_affinity are present.
-      OneOfArgumentsRequiredException: If neither cluster or multi_cluster are
-          present.
+      ConflictingArgumentsException,
+      OneOfArgumentsRequiredException:
+        See app_profiles.Update(...)
+
+    Returns:
+      Long running operation.
+    """
+    return app_profiles.Update(
+        app_profile_ref,
+        cluster=args.route_to,
+        description=args.description,
+        multi_cluster=args.route_any,
+        restrict_to=args.restrict_to,
+        transactional_writes=args.transactional_writes,
+        priority=args.priority,
+        data_boost=args.data_boost,
+        data_boost_billing_owner=args.data_boost_billing_owner,
+        force=args.force,
+    )
+
+
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+class UpdateAppProfileAlpha(UpdateAppProfileBeta):
+  """Update a Bigtable app profile."""
+
+  @staticmethod
+  def Args(parser):
+    arguments.AddAppProfileResourceArg(parser, 'to update')
+    (
+        arguments.ArgAdder(parser)
+        .AddDescription('app profile', required=False)
+        .AddAppProfileRouting(
+            required=False,
+            allow_failover_radius=True,
+            allow_row_affinity=True,
+        )
+        .AddIsolation(allow_data_boost=True)
+        .AddForce('update')
+        .AddAsync()
+    )
+
+  def _UpdateAppProfile(self, app_profile_ref, args):
+    """Updates an AppProfile with the given arguments.
+
+    Args:
+      app_profile_ref: A resource reference of the new app profile.
+      args: an argparse namespace. All the arguments that were provided to this
+        command invocation.
+
+    Raises:
+      ConflictingArgumentsException,
+      OneOfArgumentsRequiredException:
+        See app_profiles.Update(...)
 
     Returns:
       Long running operation.
@@ -185,7 +221,9 @@ class UpdateAppProfileAlpha(UpdateAppProfile):
         restrict_to=args.restrict_to,
         failover_radius=args.failover_radius,
         transactional_writes=args.transactional_writes,
-        force=args.force,
-        priority=args.priority,
         row_affinity=args.row_affinity,
+        priority=args.priority,
+        data_boost=args.data_boost,
+        data_boost_billing_owner=args.data_boost_billing_owner,
+        force=args.force,
     )
