@@ -27,7 +27,6 @@ from googlecloudsdk.command_lib.run import config_changes
 from googlecloudsdk.command_lib.run import connection_context
 from googlecloudsdk.command_lib.run import container_parser
 from googlecloudsdk.command_lib.run import flags
-from googlecloudsdk.command_lib.run import functions
 from googlecloudsdk.command_lib.run import messages_util
 from googlecloudsdk.command_lib.run import platforms
 from googlecloudsdk.command_lib.run import pretty_print
@@ -35,6 +34,7 @@ from googlecloudsdk.command_lib.run import resource_args
 from googlecloudsdk.command_lib.run import resource_change_validators
 from googlecloudsdk.command_lib.run import serverless_operations
 from googlecloudsdk.command_lib.run import stages
+from googlecloudsdk.command_lib.run.sourcedeploys import builders
 from googlecloudsdk.command_lib.util.concepts import concept_parsers
 from googlecloudsdk.command_lib.util.concepts import presentation_specs
 from googlecloudsdk.core import properties
@@ -206,11 +206,6 @@ class Deploy(base.Command):
         args, self.ReleaseTrack(), flags.Product.RUN
     )
 
-    use_wait = (
-        self.ReleaseTrack() == base.ReleaseTrack.ALPHA
-        and platforms.GetPlatform() == platforms.PLATFORM_MANAGED
-    )
-
     if flags.FlagIsExplicitlySet(args, 'containers'):
       containers = args.containers
     else:
@@ -417,6 +412,7 @@ class Deploy(base.Command):
         service = operations.ReleaseService(
             service_ref,
             changes,
+            self.ReleaseTrack(),
             tracker,
             asyn=args.async_,
             allow_unauthenticated=allow_unauth,
@@ -430,7 +426,6 @@ class Deploy(base.Command):
                 flags.FlagIsExplicitlySet(args, 'revision_suffix')
                 or flags.FlagIsExplicitlySet(args, 'tag')
             ),
-            use_wait=use_wait,
         )
 
       if args.async_:
@@ -468,7 +463,7 @@ def _CreateBuildPack(container, release_track=base.ReleaseTrack.GA):
         pack[0].update(
             {
                 'builder': '{builder}'.format(
-                    builder=functions.FunctionBuilder(
+                    builder=builders.FunctionBuilder(
                         base_image_arg
                     )
                 )
